Re: [PATCH 0/6] address packed-refs speed regressions
- From
René Scharfe <l.s.r@web.de>
- Date
- Apr 5, 2015, 23:04 UTC
- Message-ID
- <5521BF95.4030207@web.de>
- In-Reply-To
- <20150405185911.GA19902@peff.net>
Am 05.04.2015 um 20:59 schrieb Jeff King:
Show 20 quoted lines
> Still, the numbers are promising. Here's are comparisons > against for-each-ref on torvalds/linux, which has a 218M > packed-refs file: > > $ time git for-each-ref \ > --format='%(objectname) %(refname)' \ > refs/remotes/2325298/ | > wc -c > 44139 > > real 0m1.649s > user 0m1.332s > sys 0m0.304s > > $ time ~peff/git-quick-list refs/remotes/2325298/ | wc -c > 44139 > > real 0m0.012s > user 0m0.004s > sys 0m0.004s
Sweet numbers. :-P
I'm not familiar with refs.c, but its sheer size alone suggests that it won't be easy to integrate this prototype code there. :-/
René